@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getApp(vmanage):
     """
     Get policy lists
@@ -13,8 +10,8 @@ def getApp(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/app"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createApp(vmanage, policylist):
@@ -30,8 +27,8 @@ def createApp(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/app"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewApp(vmanage, policylist):
@@ -47,8 +44,8 @@ def previewApp(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/app/preview"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewAppById(vmanage, id):
@@ -64,8 +61,8 @@ def previewAppById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/app/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getAppListsById(vmanage, id):
@@ -81,8 +78,8 @@ def getAppListsById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/app/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def edit(vmanage, policylist, id):
@@ -99,8 +96,8 @@ def edit(vmanage, policylist, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/app/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policylist)
     return response
 
 def deleteApp(vmanage, id):
@@ -116,8 +113,8 @@ def deleteApp(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/app/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/list/app/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
 
 def getLocalApp(vmanage):
@@ -132,8 +129,8 @@ def getLocalApp(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/localapp"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def createLocalApp(vmanage, policylist):
@@ -149,8 +146,8 @@ def createLocalApp(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/localapp"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewLocalApp(vmanage, policylist):
@@ -166,8 +163,8 @@ def previewLocalApp(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/localapp/preview"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewLocalAppById(vmanage, id):
@@ -183,8 +180,8 @@ def previewLocalAppById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/localapp/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getLocalAppListsById(vmanage, id):
@@ -200,8 +197,8 @@ def getLocalAppListsById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/localapp/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def editLocalApp(vmanage, policylist, id):
@@ -218,8 +215,8 @@ def editLocalApp(vmanage, policylist, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/localapp/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policylist)
     return response
 
 def deleteLocalApp(vmanage, id):
@@ -235,6 +232,6 @@ def deleteLocalApp(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/localapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/list/localapp/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
