@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getNativeInfo(vmanage, deviceId):
     """
     Get device system native settings from device
@@ -14,8 +11,8 @@ def getNativeInfo(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/system/native?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/system/native?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getProcessList(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getProcessList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/system/processlist?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/system/processlist?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSetting(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getSetting(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/system/settings?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/system/settings?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatus(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/csp/system/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/csp/system/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInfoList(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getInfoList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/system/info?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/system/info?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStats(vmanage, deviceId):
     """
@@ -94,8 +91,8 @@ def getStats(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/system/statistics?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/system/statistics?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatusList(vmanage, deviceId):
     """
@@ -110,8 +107,8 @@ def getStatusList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/system/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/system/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncedStatusList(vmanage, deviceId):
     """
@@ -126,6 +123,6 @@ def getSyncedStatusList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/system/synced/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/system/synced/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
